---
title: GWAS Catalog
---

<div align="center">
  <img width="100" height="100" src="../../../../assets/imgs/GWAS_Catalog_circle_178x178.png">
  <h1>GWAS Catalog</h1>
</div>

The [GWAS Catalog](https://www.ebi.ac.uk/gwas/) is a comprehensive resource that aims to provide a curated collection of Genome-Wide Association Studies (GWAS) (including harmonized full GWAS summary statistics) across various traits and diseases in humans.

It serves as a valuable repository of genetic associations identified in diverse populations, offering insights into the genetic basis of complex traits and diseases.

We rely on the GWAS Catalog for a rich source of genetic associations, utilizing the data for analysis and interpretation.

For detailed information on specific genetic associations, their significance, and associated studies, refer to the [GWAS Catalog](https://www.ebi.ac.uk/gwas/).

Within our analyses, we leverage two different types of studies from the GWAS Catalog:

1. **Studies with (full) GWAS summary stats**

2. **Studies with top hits only - GWAS curated studies**
